@@ -1,6 +1,22 @@
 import imp, os, logging, sys
 
-DEFAULTS = {'WATERMARK': '', 'LOG_LEVEL': logging.INFO}
+DEFAULTS = {
+    'WATERMARK': '',
+    'LOG_LEVEL': logging.INFO,
+    'CACHE': {
+        'method': None,
+        'methods': {
+            's3': {
+                'bucket_name': None,
+                'path': ''
+            },
+            'disk': {
+                'dir': None,
+                'limit': None
+            }
+        }
+    }
+}
 
 INITIALIZED = False
 
@@ -8,7 +24,7 @@ def init():
     if INITIALIZED:
         return
     
-    global DATABASES, WATERMARK, LOG_LEVEL, logger
+    global DATABASES, CACHE, WATERMARK, LOG_LEVEL, logger
     
     config_file = imp.load_source('jardin_conf', os.environ.get('JARDIN_CONF', 'jardin_conf.py'))
     
