@@ -4,9 +4,9 @@ import re, inspect
 import json
 
 import jardin.config as config
-from jardin.database import DatabaseAdapter, DatabaseConnections
+from jardin.database.database_adapter import DatabaseAdapter
+from jardin.database.datasources import Datasources
 from jardin.tools import soft_del, classorinstancemethod, stack_marker
-from jardin.transaction import Transaction
 from jardin.query import query
 
 
@@ -63,6 +63,9 @@ class Model(object):
     """
       Base class from which your models should inherit.
     """
+
+    # These class variables are shared by all threads. They are intended to be set
+    # during subclass creation. After initialization they should not be changed.
     table_name = None
     table_alias = None
     db_names = {}
@@ -250,7 +253,7 @@ class Model(object):
 
         kwargs['stack'] = self.stack_mark(
             inspect.stack(),
-            db_conn=db_adapter.db
+            db_conn=db_adapter.db_client
             )
 
         return self.collection_instance(db_adapter.select(**kwargs))
@@ -342,6 +345,8 @@ class Model(object):
 
     @classmethod
     def record_or_model(self, results):
+        if results is None:
+            return None
         if len(results) == 1:
             return self(**results.to_dict(orient='records')[0])
         else:
@@ -491,7 +496,7 @@ class Model(object):
     @classmethod
     def db(self, role='replica', db_name=None):
         name = db_name or self.db_names.get(role)
-        return DatabaseConnections.connection(name)
+        return Datasources.active_client(name)
 
     @classmethod
     def _use_replica(self, **kwargs):
@@ -525,13 +530,6 @@ class Model(object):
         except:
             return 0
 
-    @classmethod
-    def transaction(self):
-        """
-        Enables multiple statements to be ran within a single transaction, see :doc:`features`.
-        """
-        return Transaction(self.db(role='master').name)
-
     @classmethod
     def table_schema(self):
         """
@@ -562,7 +560,7 @@ class Model(object):
             self.model_metadata(include_schema=False)
             )
         return db_adapter.raw_query(
-            sql=db_adapter.db.lexicon.table_schema_query(self._table_name()),
+            sql=db_adapter.db_client.lexicon.table_schema_query(self._table_name()),
             where={'table_name': self._table_name()}
             ).to_dict(orient='records')
 
