@@ -2,7 +2,8 @@ import argparse
 import os
 import inspect
 
-from jardin.database import DatabaseAdapter, DatabaseConnections
+from jardin.database.database_adapter import DatabaseAdapter
+from jardin.database.datasources import Datasources
 from jardin.tools import stack_marker
 
 def query(sql=None, filename=None, extract=None, db=None, **kwargs):
@@ -20,7 +21,7 @@ def query(sql=None, filename=None, extract=None, db=None, **kwargs):
         kwargs['where'] = kwargs['params']
 
     return DatabaseAdapter(
-        DatabaseConnections.connection(db),
+        Datasources.active_client(db),
         None
         ).raw_query(
             sql=sql, filename=filename, **kwargs
